@@ -144,9 +144,18 @@ void parse_configfile(const char *cmdpath, entropy_source_t **entropy_source_p)
   fclose(conf);
 
   /*
-   * Zero out the last entry in the table.
+   * Zero out the last entry in the table and resize the array to save some
+   * memory, evn though it shouldn't be much.
    */
   memset(entropy_source + cur_cmd, 0, sizeof(entropy_source_t));
 
+  entropy_source = realloc(entropy_source,
+			   (cur_cmd + 1)*sizeof(entropy_source_t));
+  if (!entropy_source) { 
+    fprintf(stderr, "Could not allocate entropy-command-table: %s\n",
+	    strerror(errno));
+    exit(EXIT_FAILURE);
+  }
+
   *entropy_source_p = entropy_source;
 }
