@@ -88,23 +88,22 @@ static void write_seedfile(void)
   bytes = lseek(randsavefd, 0, SEEK_SET);
   if (bytes < 0)
   {
-    if (debug)
-      fprintf(stderr, "Error writing seedfile: %s\n", strerror(errno));
+    fprintf(stderr, "Error writing seedfile: %s\n", strerror(errno));
     exit(EXIT_FAILURE);
   }
   bytes = rand_bytes(buffer, 1024);
   if (bytes == 0)
   {
-    if (debug)
-      fprintf(stderr, "Could not retrieve rand_bytes\n");
-    exit(EXIT_FAILURE);
+    fprintf(stderr, "Could not retrieve rand_bytes\n");
   }
-  bytes = write(randsavefd, buffer, 1024);
-  if (bytes < 0)
+  else
   {
-    if (debug)
+    bytes = write(randsavefd, buffer, 1024);
+    if (bytes < 0)
+    {
       fprintf(stderr, "Error writing seedfile: %s\n", strerror(errno));
-    exit(EXIT_FAILURE);
+      exit(EXIT_FAILURE);
+    }
   }
   if (debug)
     fprintf(stdout, "Wrote %d bytes back to seedfile\n", bytes);
