@@ -188,11 +188,17 @@ void main_loop(int service_socket, struct sockaddr_un sockun,
 	    fprintf(stderr, "Closing connection to gatherer\n");
 	  close(gather_fd);
 	  gather_fd = -1;
-	  gatherer_entry++;
-          if (entropy_source[gatherer_entry].path == NULL) {
-	    first_gather = 0;	/* done */
-	    gatherer_entry = 0;
-	  }
+	}
+      }
+      if (gather_fd == -1) {
+	/*
+	 * The formerly running gatherer has just been shut down for normal
+	 * or error conditions. Choose the next one.
+	 */
+	gatherer_entry++;
+        if (entropy_source[gatherer_entry].path == NULL) {
+	  first_gather = 0;	/* done */
+	  gatherer_entry = 0;
 	}
       }
     }
@@ -204,8 +210,15 @@ void main_loop(int service_socket, struct sockaddr_un sockun,
 	(difftime(time(NULL), gather_start) > seed_ext_interval / 2 + 1)) {
       kill(gatherer_pid, SIGKILL);
       gatherer_pid = -1;
-      close(gather_fd);
-      gather_fd = -1;
+      if (gather_fd != -1) {
+	close(gather_fd);
+	gather_fd = -1;
+	gatherer_entry++;
+	if (entropy_source[gatherer_entry].path == NULL) {
+	  first_gather = 0;	/* done */
+	  gatherer_entry = 0;
+	}
+      }
     }
 
     /*
